@@ -4,7 +4,6 @@
 
 
 
-#define DVB_UTILS_BUFFER_SIZE 4096
 static void _g_slist_free_g_object_unref (GSList* self);
 
 
@@ -108,14 +107,13 @@ char* dvb_utils_remove_nonalphanums (const char* text) {
 		regex = (_tmp0 = g_regex_new ("\\W", 0, 0, &inner_error), (regex == NULL) ? NULL : (regex = (g_regex_unref (regex), NULL)), _tmp0);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_REGEX_ERROR) {
-				goto __catch35_g_regex_error;
+				goto __catch28_g_regex_error;
 			}
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+			goto __finally28;
 		}
 	}
-	goto __finally35;
-	__catch35_g_regex_error:
+	goto __finally28;
+	__catch28_g_regex_error:
 	{
 		GError * e;
 		e = inner_error;
@@ -123,14 +121,19 @@ char* dvb_utils_remove_nonalphanums (const char* text) {
 		{
 			const char* _tmp1;
 			char* _tmp2;
-			g_error (e->message);
+			g_error ("Utils.vala:43: RegexError: %s", e->message);
 			_tmp1 = NULL;
 			_tmp2 = NULL;
 			return (_tmp2 = (_tmp1 = text, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), (regex == NULL) ? NULL : (regex = (g_regex_unref (regex), NULL)), _tmp2);
 		}
 	}
-	__finally35:
-	;
+	__finally28:
+	if (inner_error != NULL) {
+		(regex == NULL) ? NULL : (regex = (g_regex_unref (regex), NULL));
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+		g_clear_error (&inner_error);
+		return NULL;
+	}
 	new_text = NULL;
 	{
 		char* _tmp3;
@@ -138,16 +141,15 @@ char* dvb_utils_remove_nonalphanums (const char* text) {
 		_tmp3 = g_regex_replace_literal (regex, text, strlen (text), 0, "_", 0, &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_REGEX_ERROR) {
-				goto __catch36_g_regex_error;
+				goto __catch29_g_regex_error;
 			}
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+			goto __finally29;
 		}
 		_tmp4 = NULL;
 		new_text = (_tmp4 = _tmp3, new_text = (g_free (new_text), NULL), _tmp4);
 	}
-	goto __finally36;
-	__catch36_g_regex_error:
+	goto __finally29;
+	__catch29_g_regex_error:
 	{
 		GError * e;
 		e = inner_error;
@@ -155,14 +157,20 @@ char* dvb_utils_remove_nonalphanums (const char* text) {
 		{
 			const char* _tmp5;
 			char* _tmp6;
-			g_error (e->message);
+			g_error ("Utils.vala:51: RegexError: %s", e->message);
 			_tmp5 = NULL;
 			_tmp6 = NULL;
 			return (_tmp6 = (_tmp5 = text, (_tmp5 == NULL) ? NULL : g_strdup (_tmp5)), (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), (regex == NULL) ? NULL : (regex = (g_regex_unref (regex), NULL)), new_text = (g_free (new_text), NULL), _tmp6);
 		}
 	}
-	__finally36:
-	;
+	__finally29:
+	if (inner_error != NULL) {
+		(regex == NULL) ? NULL : (regex = (g_regex_unref (regex), NULL));
+		new_text = (g_free (new_text), NULL);
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+		g_clear_error (&inner_error);
+		return NULL;
+	}
 	_tmp7 = NULL;
 	return (_tmp7 = new_text, (regex == NULL) ? NULL : (regex = (g_regex_unref (regex), NULL)), _tmp7);
 }
@@ -171,7 +179,7 @@ char* dvb_utils_remove_nonalphanums (const char* text) {
 /**
      * @returns: Difference in seconds
      */
-gint64 dvb_utils_difftime (struct tm* t1, struct tm* t2) {
+gint64 dvb_utils_difftime (const struct tm* t1, const struct tm* t2) {
 	gint64 ts1;
 	gint64 ts2;
 	gint64 diff;
@@ -308,6 +316,7 @@ char* dvb_utils_read_file_contents (GFile* file, GError** error) {
 	GFileInputStream* stream;
 	GString* sb;
 	gchar* _tmp10;
+	gint buffer_size;
 	gint buffer_length1;
 	gchar* buffer;
 	glong bytes_read;
@@ -322,26 +331,32 @@ char* dvb_utils_read_file_contents (GFile* file, GError** error) {
 		GFileInfo* _tmp1;
 		_tmp0 = g_file_query_info (file, attrs, 0, NULL, &inner_error);
 		if (inner_error != NULL) {
-			goto __catch37_g_error;
+			goto __catch30_g_error;
+			goto __finally30;
 		}
 		_tmp1 = NULL;
 		info = (_tmp1 = _tmp0, (info == NULL) ? NULL : (info = (g_object_unref (info), NULL)), _tmp1);
 	}
-	goto __finally37;
-	__catch37_g_error:
+	goto __finally30;
+	__catch30_g_error:
 	{
 		GError * e;
 		e = inner_error;
 		inner_error = NULL;
 		{
 			char* _tmp2;
-			g_critical (e->message);
+			g_critical ("Utils.vala:125: Could not retrieve attributes: %s", e->message);
 			_tmp2 = NULL;
 			return (_tmp2 = NULL, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), attrs = (g_free (attrs), NULL), (info == NULL) ? NULL : (info = (g_object_unref (info), NULL)), _tmp2);
 		}
 	}
-	__finally37:
-	;
+	__finally30:
+	if (inner_error != NULL) {
+		g_propagate_error (error, inner_error);
+		attrs = (g_free (attrs), NULL);
+		(info == NULL) ? NULL : (info = (g_object_unref (info), NULL));
+		return NULL;
+	}
 	if (g_file_info_get_file_type (info) != G_FILE_TYPE_REGULAR) {
 		char* _tmp3;
 		char* _tmp4;
@@ -367,32 +382,37 @@ char* dvb_utils_read_file_contents (GFile* file, GError** error) {
 		_tmp7 = g_file_read (file, NULL, &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_IO_ERROR) {
-				goto __catch38_g_io_error;
+				goto __catch31_g_io_error;
 			}
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+			goto __finally31;
 		}
 		_tmp8 = NULL;
 		stream = (_tmp8 = _tmp7, (stream == NULL) ? NULL : (stream = (g_object_unref (stream), NULL)), _tmp8);
 	}
-	goto __finally38;
-	__catch38_g_io_error:
+	goto __finally31;
+	__catch31_g_io_error:
 	{
 		GError * e;
 		e = inner_error;
 		inner_error = NULL;
 		{
 			char* _tmp9;
-			g_critical (e->message);
+			g_critical ("Utils.vala:143: Could not read file: %s", e->message);
 			_tmp9 = NULL;
 			return (_tmp9 = NULL, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), attrs = (g_free (attrs), NULL), (info == NULL) ? NULL : (info = (g_object_unref (info), NULL)), (stream == NULL) ? NULL : (stream = (g_object_unref (stream), NULL)), _tmp9);
 		}
 	}
-	__finally38:
-	;
+	__finally31:
+	if (inner_error != NULL) {
+		g_propagate_error (error, inner_error);
+		attrs = (g_free (attrs), NULL);
+		(info == NULL) ? NULL : (info = (g_object_unref (info), NULL));
+		(stream == NULL) ? NULL : (stream = (g_object_unref (stream), NULL));
+		return NULL;
+	}
 	sb = g_string_new ("");
 	_tmp10 = NULL;
-	buffer = (_tmp10 = g_new0 (gchar, DVB_UTILS_BUFFER_SIZE), buffer_length1 = DVB_UTILS_BUFFER_SIZE, _tmp10);
+	buffer = (_tmp10 = g_new0 (gchar, DVB_UTILS_BUFFER_SIZE), buffer_length1 = DVB_UTILS_BUFFER_SIZE, buffer_size = buffer_length1, _tmp10);
 	bytes_read = 0L;
 	while (TRUE) {
 		gssize _tmp11;
@@ -477,7 +497,7 @@ void dvb_utils_delete_dir_recursively (GFile* dir, GError** error) {
 		if (!((childinfo = (_tmp3 = _tmp2, (childinfo == NULL) ? NULL : (childinfo = (g_object_unref (childinfo), NULL)), _tmp3)) != NULL)) {
 			break;
 		}
-		type = (guint32) g_file_info_get_attribute_uint32 (childinfo, G_FILE_ATTRIBUTE_STANDARD_TYPE);
+		type = g_file_info_get_attribute_uint32 (childinfo, G_FILE_ATTRIBUTE_STANDARD_TYPE);
 		child = g_file_get_child (dir, g_file_info_get_name (childinfo));
 		switch (type) {
 			case G_FILE_TYPE_DIRECTORY:
